@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Any
 from typing import Mapping
 from typing import cast
@@ -6,11 +8,32 @@ from jsonschema.exceptions import best_match
 from jsonschema.protocols import Validator
 from referencing import Registry
 
+from openapi_schema_validator._caches import ValidatorCache
 from openapi_schema_validator._dialects import OAS31_BASE_DIALECT_ID
 from openapi_schema_validator._dialects import OAS32_BASE_DIALECT_ID
 from openapi_schema_validator.validators import OAS32Validator
 from openapi_schema_validator.validators import check_openapi_schema
 
+_LOCAL_ONLY_REGISTRY = Registry()
+_VALIDATOR_CACHE = ValidatorCache()
+
+
+def _check_schema(
+    cls: type[Validator],
+    schema: dict[str, Any],
+) -> None:
+    meta_schema = getattr(cls, "META_SCHEMA", None)
+    # jsonschema's default check_schema path does not accept a custom
+    # registry, so for OAS dialects we use the package registry
+    # explicitly to keep metaschema resolution local and deterministic.
+    if isinstance(meta_schema, dict) and meta_schema.get("$id") in (
+        OAS31_BASE_DIALECT_ID,
+        OAS32_BASE_DIALECT_ID,
+    ):
+        check_openapi_schema(cls, schema)
+    else:
+        cls.check_schema(schema)
+
 
 def validate(
     instance: Any,
@@ -18,7 +41,8 @@ def validate(
     cls: type[Validator] = OAS32Validator,
     *args: Any,
     allow_remote_references: bool = False,
-    **kwargs: Any
+    check_schema: bool = True,
+    **kwargs: Any,
 ) -> None:
     """
     Validate an instance against a given schema using the specified
@@ -38,6 +62,9 @@ def validate(
         allow_remote_references: If ``True`` and no explicit ``registry`` is
             provided, allow jsonschema's default remote reference retrieval
             behavior.
+        check_schema: If ``True`` (default), validate the provided schema
+            before validating ``instance``. If ``False``, skip schema
+            validation and run instance validation directly.
         **kwargs: Keyword arguments forwarded to ``cls`` constructor
             (for example ``registry`` and ``format_checker``). If omitted,
             a local-only empty ``Registry`` is used to avoid implicit remote
@@ -49,25 +76,42 @@ def validate(
     """
     schema_dict = cast(dict[str, Any], schema)
 
-    meta_schema = getattr(cls, "META_SCHEMA", None)
-    # jsonschema's default check_schema path does not accept a custom
-    # registry, so for OAS dialects we use the package registry
-    # explicitly to keep metaschema resolution local and deterministic.
-    if isinstance(meta_schema, dict) and meta_schema.get("$id") in (
-        OAS31_BASE_DIALECT_ID,
-        OAS32_BASE_DIALECT_ID,
-    ):
-        check_openapi_schema(cls, schema_dict)
-    else:
-        cls.check_schema(schema_dict)
-
     validator_kwargs = kwargs.copy()
     if not allow_remote_references:
-        validator_kwargs.setdefault("registry", Registry())
+        validator_kwargs.setdefault("registry", _LOCAL_ONLY_REGISTRY)
+
+    key = _VALIDATOR_CACHE.build_key(
+        schema=schema_dict,
+        cls=cls,
+        args=args,
+        kwargs=validator_kwargs,
+        allow_remote_references=allow_remote_references,
+    )
+
+    cached = _VALIDATOR_CACHE.get(key)
+
+    if cached is None:
+        if check_schema:
+            _check_schema(cls, schema_dict)
+
+        validator = cls(schema_dict, *args, **validator_kwargs)
+        cached = _VALIDATOR_CACHE.set(
+            key,
+            validator=validator,
+            schema_checked=check_schema,
+        )
+    elif check_schema and not cached.schema_checked:
+        _check_schema(cls, schema_dict)
+        _VALIDATOR_CACHE.mark_schema_checked(key)
+    else:
+        _VALIDATOR_CACHE.touch(key)
 
-    validator = cls(schema_dict, *args, **validator_kwargs)
     error = best_match(
-        validator.evolve(schema=schema_dict).iter_errors(instance)
+        cached.validator.evolve(schema=schema_dict).iter_errors(instance)
     )
     if error is not None:
         raise error
+
+
+def clear_validate_cache() -> None:
+    _VALIDATOR_CACHE.clear()
